from django import forms
from django.utils.translation import gettext as _

from django_select2.forms import ModelSelect2Widget
from material import Fieldset, Layout

from aleksis.apps.kort.models import Card, CardPrinter


class CardForm(forms.ModelForm):
    class Meta:
        model = Card
        fields = ["person", "valid_until"]
        widgets = {
            "person": ModelSelect2Widget(
                search_fields=[
                    "first_name__icontains",
                    "last_name__icontains",
                    "short_name__icontains",
                ],
                attrs={"data-minimum-input-length": 0, "class": "browser-default"},
            ),
        }


class CardPrinterForm(forms.ModelForm):
    layout = Layout(
        Fieldset(_("Generic attributes"), "name", "location", "description"),
        Fieldset(_("Printer settings"), "cups_printer"),
    )

    class Meta:
        model = CardPrinter
        fields = ["name", "location", "description", "cups_printer"]


class PrinterSelectForm(forms.Form):
    layout = Layout("printer")
    printer = forms.ModelChoiceField(queryset=None, label=_("Card Printer"), required=True)

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        printers = CardPrinter.objects.all()
        self.fields["printer"].queryset = printers
        if printers.count() == 1:
            self.fields["printer"].initial = printers.first()
